@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 package Mojolicious::Plugin::Authentication;
-$Mojolicious::Plugin::Authentication::VERSION = '1.27';
+$Mojolicious::Plugin::Authentication::VERSION = '1.28';
 use Mojo::Base 'Mojolicious::Plugin';
 
 sub register {
@@ -29,8 +29,9 @@ sub register {
     # Unconditionally load the user based on uid in session
     my $user_loader_sub = sub {
         my $c = shift;
+        my $uid = $c->session($session_key);
 
-        if (my $uid = $c->session($session_key)) {
+        if (defined($uid)) {
             my $user = $load_user_cb->($c, $uid);
             if ($user) {
                 $c->stash($our_stash_key => { user => $user });
@@ -120,6 +121,7 @@ sub register {
         my ($c, $user, $pass, $extradata) = @_;
 
         $extradata ||= {};
+        my $uid = $validate_user_cb->($c, $user, $pass, $extradata);
 
         # if extradata contains "auto_validate", assume the passed username is in fact valid, and
         # auto_validate contains the uid; used for oAuth and other stuff that does not work with
@@ -128,7 +130,7 @@ sub register {
             $c->session($session_key => $extradata->{auto_validate});
             delete $c->stash->{$our_stash_key};
             return 1 if defined( $current_user->($c) );
-        } elsif (my $uid = $validate_user_cb->($c, $user, $pass, $extradata)) {
+        } elsif (defined($uid)) {
             $c->session($session_key => $uid);
             # Clear stash to force reload of any already loaded user object
             delete $c->stash->{$our_stash_key};
@@ -146,7 +148,7 @@ Mojolicious::Plugin::Authentication - A plugin to make authentication a bit easi
 
 =head1 VERSION
 
-version 1.27
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -371,9 +373,12 @@ Ed W
 SailingYYC (Github)
     -   For reporting an issue with routing conditions; I really should not code while sleepy, brainfarts imminent! 
 
+carragom (Github)
+    -   For fixing the bug that'd consider an uid of 0 or "0" to be a problem
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2012 Ben van Staveren.
+Copyright 2011-2015 Ben van Staveren.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
